@@ -29,6 +29,8 @@ class Connection(object):
         return cur
         
     def set_autocommit(self, value):
+        if not isinstance(value, bool):
+            raise ValueError("Parameter should be a boolean value")
         if value:
             switch = 'TRUE'
         else:
