@@ -27,7 +27,11 @@ class Cursor(object):
 
     def close(self):
         """Close the cursor. No further queries will be possible."""
-        self._cs.close()
+        try:
+            self._cs.close()
+            self._cs = None
+        except AttributeError:   # self._cs not exists
+            pass
 
     def _bind_params(self, args):
         if type(args) not in (tuple, list):
